{% if carousel %}
<div id="sliderIndex" class="carousel slide" data-ride="carousel" data-interval="{{ carousel.interval }}">
    {% if carousel.show_indicators %}
    {% include "carrousel/indicators.html" %}
    {% endif %}

    <div class="carousel-inner">
        {% include "carrousel/slide.html" %}
    </div>

    <a class="left carousel-control" href="#sliderIndex" role="button" data-slide="prev">
        <span class="glyphicon glyphicon-chevron-left"></span>
    </a>
    <a class="right carousel-control" href="#sliderIndex" role="button" data-slide="next">
        <span class="glyphicon glyphicon-chevron-right"></span>
    </a>
</div>
{% endif %}
