# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2016-09-28 02:41
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import easy_thumbnails.fields
import positions.fields


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Carrousel',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100, verbose_name='name')),
                ('slug', models.CharField(max_length=100, unique=True, verbose_name='slug')),
                ('interval', models.IntegerField(verbose_name='interval')),
                ('show_indicators', models.BooleanField(default=False, verbose_name='show indicators')),
            ],
            options={
                'verbose_name': 'carrousel',
            },
        ),
        migrations.CreateModel(
            name='Slide',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100, verbose_name='name')),
                ('position', positions.fields.PositionField(default=-1, verbose_name='position')),
                ('image', easy_thumbnails.fields.ThumbnailerImageField(blank=True, null=True, upload_to=b'slider/', verbose_name='image')),
                ('mobile_image', easy_thumbnails.fields.ThumbnailerImageField(blank=True, null=True, upload_to=b'slider/', verbose_name='mobile image')),
                ('html', models.TextField(blank=True, null=True, verbose_name='html')),
                ('html_position', models.CharField(blank=True, choices=[(b'left-top', 'Top-Left'), (b'left-mid', 'Middle-Left'), (b'left-bot', 'Bottom-Left'), (b'center-top', 'Top-Center'), (b'center-mid', 'Middle-Center'), (b'center-bot', 'Bottom-Center'), (b'right-top', 'Top-Right'), (b'right-mid', 'Middle-Right'), (b'right-bot', 'Bottom-right')], max_length=30, null=True, verbose_name='html position')),
                ('url', models.URLField(blank=True, null=True, verbose_name='url')),
                ('carrousel', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='slides', to='carrousel.Carrousel', verbose_name='carrousel')),
            ],
            options={
                'ordering': ['position'],
                'verbose_name': 'slide',
            },
        ),
    ]
